@@ -1,6 +1,5 @@
 "descript" <-
-function (X, n.print = 10, ..., print = TRUE) 
-{
+function(X, n.print=10, ..., print=TRUE){
     X <- data.matrix(X)
     n <- nrow(X)
     p <- ncol(X)
@@ -8,17 +7,16 @@ function (X, n.print = 10, ..., print = TRUE)
     ind <- subsets(p, 2)
     nind <- nrow(ind)
     pvals <- numeric(nind)
-    for (i in 1:nind) pvals[i] <- chisq.test(table(X[, ind[i, 1]], X[, ind[i, 2]]), ...)$p.value
+    for(i in 1:nind) pvals[i] <- chisq.test(table(X[, ind[i, 1]], X[, ind[i, 2]]), ...)$p.value
     res <- data.frame(ind, format.pval(pvals, digits = 1))
     names(res) <- c("Item i", "Item j", "p.value")
-    if (print) {
+    if(print){
         cat("\nProportions of positive/negative responses:\n")
         print(perc)
         cat("\nPair-wise Associations:\n")
         res <- res[order(pvals, decreasing = TRUE), ]
         row.names(res) <- 1:nind
         print(res[seq(1, min(n.print, nind)), ])
-    }
-    else list(perc = perc, pw.ass = res)
+    } else list(perc=perc, pw.ass=res)
 }
 
