@@ -1,19 +1,14 @@
 "ltm" <-
-function (formula, start.val, constraint = NULL, na.action = NULL, 
-    control = list()) 
-{
+function(formula, start.val, constraint=NULL, na.action=NULL, control=list()){
     cl <- match.call()
     av <- all.vars(formula)
-    X <- get(av[1], env = parent.frame())
+    X <- get(av[1], env=parent.frame())
     X <- data.matrix(X)
-    if (!is.null(na.action)) 
-        X <- na.action(X)
+    if(!is.null(na.action)) X <- na.action(X)
     dimnames(X) <- NULL
-    if (any(!av[-1] %in% c("z1", "z2"))) 
-        stop("\nYou have to use `z1' and/or `z2' to denote the factors.")
+    if(any(!av[-1] %in% c("z1", "z2"))) stop("\nYou have to use `z1' and/or `z2' to denote the factors.")
     factors <- length(av[-1])
-    if (factors > 2) 
-        stop("\nMaximum number of factors to include is 2.")
+    if(factors > 2) stop("\nMaximum number of factors to include is 2.")
     tm <- attr(terms(formula), "term.labels")
     inter <- "z1:z2" %in% tm
     quad.z1 <- "I(z1^2)" %in% tm
@@ -35,12 +30,11 @@ function (formula, start.val, constraint = NULL, na.action = NULL,
             warning("not acceptable values for the constraint, see '?ltm' for more info; 'constraint' is set to NULL\n")
         }
     }
-    con <- list(iter.em = 40, iter.qN = 150, GHk = 15, method = "BFGS", verbose = FALSE)
+    con <- list(iter.em=40, iter.qN=150, GHk=15, method="BFGS", verbose=FALSE)
     con[names(control)] <- control
-    fit <- ltm.fit(X, betas, constraint, factors, inter, quad.z1, 
-        quad.z2, con)
+    fit <- ltm.fit(X, betas, constraint, factors, inter, quad.z1, quad.z2, con)
     fit$X <- X
-    fit$ltn.struct <- c("z1", "z2", "z1:z2", "z1^2", "z2^2")[c("z1" %in% av, "z2" %in% av, inter, quad.z1, quad.z2)]
+    fit$ltn.struct <- c("z1", "z2", "z1:z2", "z1^2", "z2^2")[c("z1"%in%av, "z2"%in%av, inter, quad.z1, quad.z2)]
     fit$control <- con
     fit$call <- cl
     class(fit) <- "ltm"
