@@ -1,7 +1,6 @@
 "score.ltm" <-
-function (betas, constraint) 
-{
-    if (!is.null(constraint)) {
+function(betas, constraint){
+    if(!is.null(constraint)){
         betas. <- numeric(p * q.)
         ind <- constraint[1] + constraint[2] * p
         betas.[-ind] <- betas
@@ -15,14 +14,12 @@ function (betas, constraint)
     p.zx <- p.xz / p.x
     Nt <- GHw * colSums(p.zx * obs)
     scores <- matrix(0, p, q.)
-    for (i in 1:p) {
-        ind <- !na.ind[, i]
-        rit <- if (all(ind)) GHw * colSums(p.zx * X[, i] * obs) else GHw * colSums(p.zx[ind, ] * X[ind, i] * obs[ind])
+    for (i in 1:p){
+        ind. <- !na.ind[, i]
+        rit <- if(all(ind.)) GHw*colSums(p.zx * X[, i] * obs) else GHw*colSums(p.zx[ind., ] * X[ind., i] * obs[ind.])
         scores[i, ] <- -c(crossprod(rit - pr[, i] * Nt, Z))
     }
-    res <- if (!is.null(constraint)) 
-        c(scores)[-(constraint[1] + constraint[2] * p)]
-    else c(scores)
+    res <- if(!is.null(constraint)) c(scores)[-(constraint[1] + constraint[2] * p)] else c(scores)
     res
 }
 
